# matrix operations

This is a matrix operations package.
This matrix package has   modules
1.mat_input(rows,columns)-enter rows and columns
2.unit_mat(dimension)-unit matrix is presents of 1 in diagonals.enter the no.of.rows or columns
3.constant_mat(constant,dimension)-constant matrix contains same numbers.enter the constant and no.of.rows
4.mat_multiple(matrix1,matrix2):
                  normal matrix multiplication
5.mat_add(matrix1,matrix2): matrix addition
6.mat_sub(matrix1,matrix2): matrix subtraction
7.mat_div(matrix1,matrix2): matrix division
8.mat_trace(matrix1): trace of matrix
9.mat_transpose(matrix1): transpose of the matrix
10.det(matrix1): determinant of 2x2 , 3x3 matrix
11.adjoint(matrix1): adjoint of matrix 2x2 and 3x3 matrix
12.area(point1,point2,point3): area of triangle
13.cramer(equation matrix,equal to matrix): value of x,y or x,y,z for three equations
14.mat_inverse(matrix1): inverse of matrix
15.mat_mul(matrix1,matrix2): normal multiplication of matrix
16.mul_commutative(matrix1,matrix2): commutative property on multiplication
17.mul_assosiative(matrix1,matrix2,matrix3): assosiative property on multiplication
18.mul_distributive(matrix1,matrix2,matrix3): distributive property of matrix
19.add_commutative(matrix1,matrix2): commutative property on addition of matrix
20.add_assosiative(matrix1,matrix2,matrix3): associative property oon addition
21.additive_identity(matrix1,matrix2): additive identity of matrix
22.additive inverse(matrix1,matrix2): additive inverse of matrix
23.unitnum_mat(constant,dimension): diagonals have give number
24.mat_ortho(matrix1): orthogonal property of matrix
25.double transpose(matirx1): tranpose of a tranpose matrix:((a)T)T=a
26.sum_transpose(matrix1): transpose of sum of two matrix=sum of two transpose matrix   (a+b)T=(a)T+(b)T
27.mul_transpose(matrix1):multiplication transpose is (a*b)T=(b)T * (a)T
28.scalar_mul_transpose(matrix1):multiplication of constant with a matrix whole transpose = multiplication of a constant with the transpose of matrix  (const*a)T=const * (a)T

You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.